aboutsummaryrefslogtreecommitdiff
path: root/roomserver/api/output.go
diff options
context:
space:
mode:
Diffstat (limited to 'roomserver/api/output.go')
-rw-r--r--roomserver/api/output.go6
1 files changed, 4 insertions, 2 deletions
diff --git a/roomserver/api/output.go b/roomserver/api/output.go
index 16b50495..852b6420 100644
--- a/roomserver/api/output.go
+++ b/roomserver/api/output.go
@@ -215,8 +215,10 @@ type OutputNewInviteEvent struct {
type OutputRetireInviteEvent struct {
// The ID of the "m.room.member" invite event.
EventID string
- // The target user ID of the "m.room.member" invite event that was retired.
- TargetUserID string
+ // The room ID of the "m.room.member" invite event.
+ RoomID string
+ // The target sender ID of the "m.room.member" invite event that was retired.
+ TargetSenderID spec.SenderID
// Optional event ID of the event that replaced the invite.
// This can be empty if the invite was rejected locally and we were unable
// to reach the server that originally sent the invite.